User docs
=========

.. warning::
  It can be tricky to know if a username, or an email should be provided to login,
  especially when using app password. Refer to
  `the skpy docs <https://skpy.t.allofti.me/guides/login.html>`_ in case of trouble.

Roster
******

Contact JIDs are of the form ``username@slidge-skype.example.org`` where ``username`` is a
skype username or microsoft live account.
